<?php /* Smarty version Smarty-3.1.21-dev, created on 2017-04-28 08:25:02
         compiled from "ls:view.tpl" */ ?>
<?php /*%%SmartyHeaderCode:4558762805902fc5e4acad4-18605049%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'bba6ee792d4eef9885de9f88ca7e9ab08b301591' => 
    array (
      0 => 'ls:view.tpl',
      1 => 1485342206,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '4558762805902fc5e4acad4-18605049',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'pagetitle' => 0,
    'LSview_actions' => 0,
    'item' => 0,
    'LSrelations' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_5902fc5e4d5398_78899024',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_5902fc5e4d5398_78899024')) {function content_5902fc5e4d5398_78899024($_smarty_tpl) {?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

    <?php if ($_smarty_tpl->tpl_vars['pagetitle']->value!='') {?><h1 id='LSview_title'><?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;?>
</h1><?php }?>
    <?php if ($_smarty_tpl->tpl_vars['LSview_actions']->value!='') {?>
    <ul class='LSview-actions'>
      <?php  $_smarty_tpl->tpl_vars['item'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['item']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSview_actions']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['item']->key => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['item']->_loop = true;
?>
        <?php if (is_array($_smarty_tpl->tpl_vars['item']->value)) {?>
        <li class='LSview-actions'><a href="<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
" class="LSview-actions<?php if ($_smarty_tpl->tpl_vars['item']->value['class']) {?> <?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['class']);
}
if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']||($_smarty_tpl->tpl_vars['item']->value['hideLabel']&&$_smarty_tpl->tpl_vars['item']->value['label'])) {?> LStips<?php }?>" <?php if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']||($_smarty_tpl->tpl_vars['item']->value['hideLabel']&&$_smarty_tpl->tpl_vars['item']->value['label'])) {?>title="<?php if ($_smarty_tpl->tpl_vars['item']->value['helpInfo']) {
echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['helpInfo']);
} else {
echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);
}?>"<?php }?>><img src="<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
" alt="<?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);?>
" title="<?php echo preg_replace("%(?<!\\\\)'%", "\'",$_smarty_tpl->tpl_vars['item']->value['label']);?>
" /><?php if (!isset($_smarty_tpl->tpl_vars['item']->value['hideLabel'])||!$_smarty_tpl->tpl_vars['item']->value['hideLabel']) {?> <?php echo $_smarty_tpl->tpl_vars['item']->value['label'];
}?></a></li>
        <?php }?>
      <?php } ?>
    </ul>
    <?php }?>
    
    <?php echo $_smarty_tpl->getSubTemplate ('ls:LSform_view.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

    
    <?php if ($_smarty_tpl->tpl_vars['LSrelations']->value!='') {?>
      <?php  $_smarty_tpl->tpl_vars['item'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['item']->_loop = false;
 $_from = $_smarty_tpl->tpl_vars['LSrelations']->value; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
foreach ($_from as $_smarty_tpl->tpl_vars['item']->key => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['item']->_loop = true;
?>
        <?php echo $_smarty_tpl->getSubTemplate ('ls:LSrelations.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

      <?php } ?>
    <?php }?>
<?php echo $_smarty_tpl->getSubTemplate ('ls:bottom.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>

<?php }} ?>
